==> jc-1.4.5.tar.gz: org/omg/CORBA/PRIVATE__5fMEMBER.c <==
// public abstract interface org.omg.CORBA.PRIVATE_MEMBER

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class a3b8242fbb94dde3 org_omg_CORBA_PRIVATE__5fMEMBER

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header org_omg_CORBA_PRIVATE__5fMEMBER

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "org/omg/CORBA/PRIVATE__5fMEMBER.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// public static final int value
static const jint _jc_org_omg_CORBA_PRIVATE__5fMEMBER$initial_value$value = 0;
static _jc_field _jc_org_omg_CORBA_PRIVATE__5fMEMBER$field_info$value = {
	.name=		"value",
	.signature=	"I",
	.class=		&_jc_org_omg_CORBA_PRIVATE__5fMEMBER$type,
	.type=		&_jc_int$prim$type,
	.access_flags=	_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_org_omg_CORBA_PRIVATE__5fMEMBER$fields_struct, value),
	.initial_value=	&_jc_org_omg_CORBA_PRIVATE__5fMEMBER$initial_value$value,
};

// Fields
static _jc_field *const _jc_org_omg_CORBA_PRIVATE__5fMEMBER$fields[] = {
	&_jc_org_omg_CORBA_PRIVATE__5fMEMBER$field_info$value
};

/************************************************************************
 *			       Method list				*
 ************************************************************************/

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_org_omg_CORBA_PRIVATE__5fMEMBER$fields_struct _jc_org_omg_CORBA_PRIVATE__5fMEMBER$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_org_omg_CORBA_PRIVATE__5fMEMBER$instanceof_hash_bucket_99[] = {
	&_jc_org_omg_CORBA_PRIVATE__5fMEMBER$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_PRIVATE__5fMEMBER$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_org_omg_CORBA_PRIVATE__5fMEMBER$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[99]=	_jc_org_omg_CORBA_PRIVATE__5fMEMBER$instanceof_hash_bucket_99,
	[101]=	_jc_org_omg_CORBA_PRIVATE__5fMEMBER$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_org_omg_CORBA_PRIVATE__5fMEMBER$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_org_omg_CORBA_PRIVATE__5fMEMBER$vtype _jc_org_omg_CORBA_PRIVATE__5fMEMBER$type = {
    .type= {
	.name=			"org/omg/CORBA/PRIVATE_MEMBER",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT|_JC_ACC_INTERFACE,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0xa3b8242fbb94dde3),
		.source_file=		"PRIVATE_MEMBER.java",
		.num_virtual_refs=	0,
		.num_fields=		sizeof(_jc_org_omg_CORBA_PRIVATE__5fMEMBER$fields) / sizeof(*_jc_org_omg_CORBA_PRIVATE__5fMEMBER$fields),
		.fields=		_jc_org_omg_CORBA_PRIVATE__5fMEMBER$fields,
		.instanceof_hash_table=	_jc_org_omg_CORBA_PRIVATE__5fMEMBER$instanceof_hash_table,
		.class_fields=		&_jc_org_omg_CORBA_PRIVATE__5fMEMBER$class_fields,
		.num_class_depends=		sizeof(_jc_org_omg_CORBA_PRIVATE__5fMEMBER$class_depends) / sizeof(*_jc_org_omg_CORBA_PRIVATE__5fMEMBER$class_depends),
		.class_depends=		_jc_org_omg_CORBA_PRIVATE__5fMEMBER$class_depends,
	    }
	}
    }
};

==> jc-1.4.6.tar.gz: org/omg/CORBA/PRIVATE__5fMEMBER.c <==
// public abstract interface org.omg.CORBA.PRIVATE_MEMBER

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c25a545561a18c38 java_lang_String
// @dep_class 326ac5e263974d18 org_omg_CORBA_PRIVATE__5fMEMBER

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header org_omg_CORBA_PRIVATE__5fMEMBER

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "org/omg/CORBA/PRIVATE__5fMEMBER.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// public static final short value
static const jshort _jc_org_omg_CORBA_PRIVATE__5fMEMBER$initial_value$value = 0;
static _jc_field _jc_org_omg_CORBA_PRIVATE__5fMEMBER$field_info$value = {
	.name=		"value",
	.signature=	"S",
	.class=		&_jc_org_omg_CORBA_PRIVATE__5fMEMBER$type,
	.type=		&_jc_short$prim$type,
	.access_flags=	_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_org_omg_CORBA_PRIVATE__5fMEMBER$fields_struct, value),
	.initial_value=	&_jc_org_omg_CORBA_PRIVATE__5fMEMBER$initial_value$value,
};

// Fields
static _jc_field *const _jc_org_omg_CORBA_PRIVATE__5fMEMBER$fields[] = {
	&_jc_org_omg_CORBA_PRIVATE__5fMEMBER$field_info$value
};

/************************************************************************
 *			       Method list				*
 ************************************************************************/

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_org_omg_CORBA_PRIVATE__5fMEMBER$fields_struct _jc_org_omg_CORBA_PRIVATE__5fMEMBER$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_org_omg_CORBA_PRIVATE__5fMEMBER$instanceof_hash_bucket_24[] = {
	&_jc_org_omg_CORBA_PRIVATE__5fMEMBER$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_PRIVATE__5fMEMBER$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_org_omg_CORBA_PRIVATE__5fMEMBER$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[24]=	_jc_org_omg_CORBA_PRIVATE__5fMEMBER$instanceof_hash_bucket_24,
	[101]=	_jc_org_omg_CORBA_PRIVATE__5fMEMBER$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_org_omg_CORBA_PRIVATE__5fMEMBER$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0xc25a545561a18c38) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_org_omg_CORBA_PRIVATE__5fMEMBER$vtype _jc_org_omg_CORBA_PRIVATE__5fMEMBER$type = {
    .type= {
	.name=			"org/omg/CORBA/PRIVATE_MEMBER",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT|_JC_ACC_INTERFACE,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x326ac5e263974d18),
		.source_file=		"PRIVATE_MEMBER.java",
		.num_virtual_refs=	0,
		.num_fields=		sizeof(_jc_org_omg_CORBA_PRIVATE__5fMEMBER$fields) / sizeof(*_jc_org_omg_CORBA_PRIVATE__5fMEMBER$fields),
		.fields=		_jc_org_omg_CORBA_PRIVATE__5fMEMBER$fields,
		.instanceof_hash_table=	_jc_org_omg_CORBA_PRIVATE__5fMEMBER$instanceof_hash_table,
		.class_fields=		&_jc_org_omg_CORBA_PRIVATE__5fMEMBER$class_fields,
		.num_class_depends=		sizeof(_jc_org_omg_CORBA_PRIVATE__5fMEMBER$class_depends) / sizeof(*_jc_org_omg_CORBA_PRIVATE__5fMEMBER$class_depends),
		.class_depends=		_jc_org_omg_CORBA_PRIVATE__5fMEMBER$class_depends,
	    }
	}
    }
};
